pub fn compare_receipts_root_and_logs_bloom(
calculated_receipts_root: B256,
calculated_logs_bloom: Bloom,
expected_receipts_root: B256,
expected_logs_bloom: Bloom,
) -> Result<(), ConsensusError>Expand description
Compare the calculated receipts root with the expected receipts root, also compare the calculated logs bloom with the expected logs bloom.