pub struct EthBeaconConsensus<ChainSpec> { /* private fields */ }Expand description
Ethereum beacon consensus
This consensus engine does basic checks as outlined in the execution specs.
Implementations
Sourceimpl<ChainSpec: EthChainSpec + EthereumHardforks> EthBeaconConsensus<ChainSpec>
impl<ChainSpec: EthChainSpec + EthereumHardforks> EthBeaconConsensus<ChainSpec>
Sourcepub const fn new(chain_spec: Arc<ChainSpec>) -> Self
pub const fn new(chain_spec: Arc<ChainSpec>) -> Self
Create a new instance of EthBeaconConsensus
Sourcepub const fn max_extra_data_size(&self) -> usize
pub const fn max_extra_data_size(&self) -> usize
Returns the maximum allowed extra data size.
Sourcepub const fn with_max_extra_data_size(self, size: usize) -> Self
pub const fn with_max_extra_data_size(self, size: usize) -> Self
Sets the maximum allowed extra data size and returns the updated instance.
Sourcepub const fn with_skip_gas_limit_ramp_check(self, skip: bool) -> Self
pub const fn with_skip_gas_limit_ramp_check(self, skip: bool) -> Self
Disables the gas limit change validation between parent and child blocks.
Sourcepub const fn with_skip_blob_gas_used_check(self, skip: bool) -> Self
pub const fn with_skip_blob_gas_used_check(self, skip: bool) -> Self
Disables the blob gas used check in header validation.
Sourcepub const fn with_skip_requests_hash_check(self, skip: bool) -> Self
pub const fn with_skip_requests_hash_check(self, skip: bool) -> Self
Disables the requests hash check in post-execution validation.
Sourcepub const fn chain_spec(&self) -> &Arc<ChainSpec>
pub const fn chain_spec(&self) -> &Arc<ChainSpec>
Returns the chain spec associated with this consensus engine.